@@ -12,6 +12,7 @@ from tinymce.widgets import TinyMCE
 from tendenci.core.base.fields import SplitDateTimeField
 from tendenci.core.base.fields import EmailVerificationField
 from tendenci.core.files.utils import get_max_file_upload_size
+from tendenci.core.perms.utils import get_query_filters
 from tendenci.apps.user_groups.models import Group
 
 ALLOWED_LOGO_EXT = (
@@ -42,7 +43,7 @@ class NewsForm(TendenciBaseForm):
     photo_upload = forms.FileField(label=_('Thumbnail Image'), required=False, help_text=_('The thumbnail image can be used on your homepage or sidebar if it is setup in your theme. It will not display on the news page.'))
     remove_photo = forms.BooleanField(label=_('Remove the current photo'), required=False)
 
-    group = forms.ModelChoiceField(queryset=Group.objects.filter(status=True, status_detail="active"), required=True, empty_label=None)
+    group = forms.ChoiceField(required=True, choices=[])
 
     class Meta:
         model = News
@@ -130,6 +131,15 @@ class NewsForm(TendenciBaseForm):
 
         return photo_upload
 
+    def clean_group(self):
+        group_id = self.cleaned_data['group']
+
+        try:
+            group = Group.objects.get(pk=group_id)
+            return group
+        except Group.DoesNotExist:
+            raise forms.ValidationError(_('Invalid group selected.'))
+
     def save(self, *args, **kwargs):
         news = super(NewsForm, self).save(*args, **kwargs)
         if self.cleaned_data.get('remove_photo'):
@@ -144,11 +154,26 @@ class NewsForm(TendenciBaseForm):
             self.fields['body'].widget.mce_attrs['app_instance_id'] = 0
             self.fields['group'].initial = Group.objects.get_initial_group_id()
 
+        default_groups = Group.objects.filter(status=True, status_detail="active")
+
         #if not self.user.profile.is_superuser:
         if self.user and not self.user.profile.is_superuser:
             if 'status_detail' in self.fields:
                 self.fields.pop('status_detail')
 
+            filters = get_query_filters(self.user, 'user_groups.view_group', **{'perms_field': False})
+            groups = default_groups.filter(filters).distinct()
+            groups_list = list(groups.values_list('pk', 'name'))
+
+            users_groups = self.user.profile.get_groups()
+            for g in users_groups:
+                if [g.id, g.name] not in groups_list:
+                    groups_list.append([g.id, g.name])
+        else:
+            groups_list = default_groups.values_list('pk', 'name')
+
+        self.fields['group'].choices = groups_list
+
         # only show the remove photo checkbox if there is already a thumbnail
         if self.instance.thumbnail:
             self.fields['photo_upload'].help_text = '<input name="remove_photo" id="id_remove_photo" type="checkbox"/> Remove current image: <a target="_blank" href="/files/%s/">%s</a>' % (self.instance.thumbnail.pk, basename(self.instance.thumbnail.file.name))
